@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.0.9"
+version = "0.1.1"
 
 # tested on remi version = "2020.3.10"
 import remi.gui as gui
@@ -373,7 +373,7 @@ class CSinSCApp:
   title = "CSinSchools Application"
 
   def __init__(self, title = "CSinSchools Application", width = "100%", height = "100%"):
-    if title is None:
+    if title is None or len(title) == 0:
       raise Exception("Please supply a title for the application.")
     self.events = []  
     self.initialised = False
@@ -403,7 +403,7 @@ class CSinSCApp:
     control.widget.onmousemove.do(self.on_mouse_move, control)
 
   def remi_thread(self):
-    start(CSinSCApp.MyApp, title = CSinSCApp.title, debug=False, address='0.0.0.0', port=0, multiple_instance = True, userdata = (self,))    
+    start(CSinSCApp.MyApp, title = CSinSCApp.title, debug=False, address='0.0.0.0', port=0, multiple_instance = False, userdata = (self,))    
 
   def main(self):
     self.initialised = True
@@ -482,10 +482,14 @@ class CSinSCApp:
       del self.events[0]
     return event
 
-  def wait_for_event(self):
-    while len(self.events) == 0:
-      pass
-    event = self.events[0]
-    del self.events[0]
+  def wait_for_event(self, event_types = None):
+    bool accept = False
+    while not accept:
+      if len(self.events) == 0:
+        continue
+      event = self.events[0]
+      del self.events[0]
+      if event_types is None or event.type in event_types or event.type == event_types:
+        accept = True               
     return event
       
